/**
  *  \file client/tiles/ufoinfo.cc
  *
  *  (c) 2001-2013 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/tiles/ufoinfo.h"
#include "game/ufo.h"
#include "ui/uiglobal.h"
#include "cpluslib/format.h"
#include "util/nls.h"
#include "gfx/palette.h"
#include "ui/util.h"
#include "game/format.h"

/****************************** WUfoInfoTile *****************************/

WUfoInfoTile::WUfoInfoTile(GObjectSelection& selection)
    : WObjectSelectionObserverTile(font_sizes[FONT_NORMAL].scaledBy(30, 9), selection)
{ }

void
WUfoInfoTile::drawData(GfxCanvas& can)
{
    GUfo* u = dynamic_cast<GUfo*>(getCurrentObject());
    if (!u)
        return;

    // Info1
    // Info2
    // Location:     (X,Y)
    // Radius:       N ly
    // Speed:        warp x
    // Heading:      unknown
    // Visible at:   n ly (from planet)
    //               n ly (from ship)
    // Last seen:    this turn

    GfxRect pos = getInnerSize(0, 0);
    const int dy = font_heights[FONT_NORMAL];
    const int x0 = font_ems[FONT_NORMAL];
    const int x1 = font_ems[FONT_NORMAL]*13;
    const int w  = pos.w - x1;
    int y = 0;
    string_t tmp;

    // Ufo color indicator
    drawFrameDown(can, GfxRect(pos.x, pos.y, x0/2+2, dy*9));
    drawSolidBar(can, GfxRect(pos.x+1, pos.y+1, x0/2, dy*9-2), standard_colors[u->getColor()]);

    GfxContext ctx;
    ctx.useCanvas(can);
    ctx.useColorScheme(getSkin());
    ctx.useFont(*fonts[FONT_NORMAL]);
    ctx.setSolidBackground();
    ctx.setColor(UIColor::tc_Static);

    // Lines 1, 2:
    outTextF(ctx, x0, y, pos.w-x0, u->getInfo1());
    y += dy;
    outTextF(ctx, x0, y, pos.w-x0, u->getInfo2());
    y += dy;

    // Line 3:
    outText (ctx, x0, y, _("Location:"));
    outTextF(ctx, x1, y, w, format("(%d,%d)", u->getPos().x, u->getPos().y));
    y += dy;

    // Line 4:
    outText (ctx, x0, y, _("Radius:"));
    if (u->getRadius() <= 0)
        tmp = _("(small)");
    else
        tmp = format(_("%d ly"), u->getRadius());
    outTextF(ctx, x1, y, w, tmp);
    y += dy;

    // Line 5:
    outText (ctx, x0, y, _("Speed:"));
    if (u->getSpeed() <= 0)
        tmp = _("not moving");
    else
        tmp = format(_("warp %d"), u->getSpeed());
    outTextF(ctx, x1, y, w, tmp);
    y += dy;

    // Line 6:
    outText (ctx, x0, y, _("Heading:"));
    if (u->getHeading() < 0)
        tmp = _("unknown");
    else
        tmp = format("%d" "\xC2\xB0", u->getHeading());
    if (u->getMovementVector().x != 0 || u->getMovementVector().y != 0)
        tmp += format(" (%+d,%+d)", u->getMovementVector().x, u->getMovementVector().y);
    outTextF(ctx, x1, y, w, tmp);
    y += dy;

    // Line 7, 8:
    outText (ctx, x0, y, _("Visible at:"));
    outTextF(ctx, x1, y, w, format(_("%d ly (from planet)"), u->getPlanetRange()));
    y += dy;
    outTextF(ctx, x1, y, w, format(_("%d ly (from ship)"), u->getShipRange()));
    y += dy;

    // Line 9:
    outText (ctx, x0, y, _("Last info:"));
    outTextF(ctx, x1, y, w, formatTurnNumber(u->getLastTurn()));
    y += dy;
}
