/**
  *  \file game/actions/preconditions.cc
  *  \brief Action Preconditions
  */

#include "game/actions/preconditions.h"
#include "game/ship.h"
#include "game/planet.h"
#include "game/error.h"
#include "game/global.h"
#include "util/nls.h"

/** Check for a ship that is played.
    Throws if it is not.
    If this returns normally, the ship is played and has full data. */
void
mustBePlayed(const GShip& ship)
{
    if (!ship.isPlayable(GObject::Playable)) {
        throw GError(GError::eNotPlaying, _("You do not play this ship"));
    }
}

/** Check for a planet that is played.
    Throws if it is not.
    If this returns normally, the planet is played and has full data. */
void
mustBePlayed(const GPlanet& planet)
{
    if (!planet.isPlayable(GObject::Playable)) {
        throw GError(GError::eNotPlaying, _("You do not play this planet"));
    }
}

/** Check for a planet that has a base and is played.
    Throws if it is not.
    If this returns normally, the planet has a base, is played and has full data. */
void
mustHavePlayedBase(const GPlanet& planet)
{
    mustBePlayed(planet);
    if (!planet.hasBase()) {
        throw GError(GError::eNoBase, _("The planet does not have a starbase"));
    }
}

/** Check for a turn.
    Throws if there is no displayed turn. */
void
mustHaveTurn()
{
    if (!haveDisplayedTurn()) {
        throw GError(GError::eUser, _("No race loaded"));
    }
}
