/**
  *  \file gfx/font.h
  *  \brief Font Driver Interface
  *
  *  (c) 2001-2013 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_GFX_FONT_H
#define PCC_V2_GFX_FONT_H

#include <string>
#include "gfx/gfx.h"
#include "gfx/gfxcontext.h"
#include "cpluslib/smartptr.h"

class GfxFont : public Object {
 public:
    /** Font driver capabilities. */
    enum {
        FN_LINEAR   = 1,        /**< Linear, i.e. no kerning, huge descends, etc. */
        FN_SCALABLE = 2,        /**< Scalable, i.e. setScale() works */
        FN_ALPHA    = 4         /**< Alpha, i.e. outText() uses \c parm.alpha */
    };

    /** Output text using the specified parameters.
        \param ctx    graphics context. outText() should use canvas, color, and alpha;
                      and it should \em not use just_x/just_y.
        \param x,y    coordinates (top-left pixel)
        \param text   text */
    virtual void outText(GfxContext& ctx, GfxPoint pt, string_t text) = 0;
    virtual int getTextWidth(string_t text) = 0;
    virtual int getTextHeight(string_t text) = 0;

    virtual bool setScale(int mul, int div) = 0;
    virtual GfxPoint getScale() = 0;

    virtual unsigned getCapabilities() = 0;
};

void outText(GfxContext& ctx, int x, int y, string_t text);
void outText(GfxContext& ctx, int x, int y, const char* text);
void outTextF(GfxContext& ctx, int x, int y, int maxw, string_t text);
void outTextF(GfxContext& ctx, int x, int y, int maxw, const char* text);
void outTextF(GfxContext& ctx, const GfxRect& area, string_t text);
void outTextF(GfxContext& ctx, const GfxRect& area, const char* text);

#endif
